#include "distance.hpp"
#include <cmath>

void normalize(point3D& p) {

  double norm = sqrt(p.x*p.x + p.y*p.y + p.z*p.z);
  if (fabs(norm)>1.e-16) {
    p.x /= norm; 
    p.y /= norm; 
    p.z /= norm; 
  }
}

namespace EuclidianGeom {

  double distance(point3D& p1, point3D& p2) {
    normalize(p1);
    normalize(p2);
    return sqrt(pow(p2.x-p1.x,2) +  pow(p2.y-p1.y,2) + pow(p2.z-p1.z,2));
  }

}

namespace SphereGeom {

  double distance(point3D& p1, point3D& p2) {
    normalize(p1);
    normalize(p2);
    return acos(p1.x*p2.x + p1.y*p2.y + p1.z*p2.z);
  }

}
