#include <iostream>
#include <fstream>
#include "sparseMatrix.hpp"

int main() {

  sparseMatrix A;
  int          N  = 100;
  double       dx = M_PI/(N-1.);
  double       dt = 0.01;
  fill1DHeat(A,dx,dt,N);

  // We test heat(u) = O for x in [0,pi]
  // with u0 = sin(x)
  // solution is exp(-t)sin(x)
  std::vector<double> B(N);
  for (uint i=0u;i<B.size();i++)
    B[i] = sin(i*dx)/dt;

  std::vector<double> u(N);
  solveCG(A,B,u);

  double normSol  = 0.e0;
  double normDiff = 0.e0;
  for (uint i=0u;i<B.size();i++) {
    normSol  += pow(exp(-dt)*sin(i*dx),2);
    normDiff += pow(exp(-dt)*sin(i*dx)-u[i],2);
  }
  std::cout << "Relative error between solution and approx by CG: " << sqrt(normDiff/normSol) << std::endl;

}



